@@ -49,7 +49,9 @@ def generate_actions_from_irc_message(args,printer):
     if debug:
         printer("", "to_me: " + str(to_me) + ", from_me: " + str(from_me) + ", monitoring_channel: " + str(monitoring_channel))
 
-    if not to_me and not from_me and monitoring_channel:
+    ignore_message = should_ignore(message)
+
+    if not to_me and not from_me and monitoring_channel and not ignore_message:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
         alert_title, alrt_msg = construct_alert(from_who, channel, message, elapsed_time)
         actions_todo.append({"action": display_alert,
@@ -94,38 +96,17 @@ def play_sound(args,printer):
     call(cmd)
 
 
-#########################
-## TESTS
-
-def _tests():
-    test_trim_leading_dashes()
-    test_begins_with_dash ()
-
-def test_trim_leading_dashes():
-    strng = "-abc"
-    result = trim_leading_dashes(strng)
-    assert result == "abc"
-    strng = "--abc"
-    result = trim_leading_dashes(strng)
-    assert result == "abc"
-    strng = "abc"
-    result = trim_leading_dashes(strng)
-    assert result == "abc"
-
-def test_begins_with_dash ():
-    strng = "-abc"
-    result = begins_with_dash(strng)
-    assert result == True
-    strng = "--abc"
-    result = begins_with_dash(strng)
-    assert result == True
-    strng = "abc"
-    result = begins_with_dash(strng)
-    assert result == False
     
 ##########################
 ## HELPERS
 
+def should_ignore(message):
+    ignore_messages = [ "has joined #" ]
+    for msg_to_ignore in ignore_messages:
+        if message.find(msg_to_ignore):
+            return True
+    return false
+
 def trim_leading_dashes(strng):
     # pdb.set_trace()
     while begins_with_dash(strng):
@@ -227,5 +208,124 @@ def print_sep(sleep_seconds):
     print("-------------------------------")
     time.sleep(sleep_seconds)
 
+
+
+############################################
+# TEST HELPERS
+
+start_time = time.time()
+
+def printer(arg):
+    print arg
+
+def fenton_writes_on_lisp():
+    # I write a question on channel #lisp
+    init( { "username": "fenton", "monitor_time": 5 } )
+
+    incoming_message = { "from_who": "fenton",
+                         "channel" : "lisp",
+                         "message" : "john clean up your mess!",
+                         "to_me"   : False }
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    # pdb.set_trace()
+    printall(incoming_message, response_actions,start_time)
+    perform_actions(response_actions,printer)
+
+############################################
+# SYSTEM TESTS
+
+def system_tests():
+    test_ignore_join_leave()
+    # test_system_1()
+
+def test_ignore_join_leave():
+    fenton_writes_on_lisp()
+    print_sep(sleep_seconds = 0)
+    incoming_message = { "from_who": "abcdef",
+                         "channel" : "lisp",
+                         "message" : "john has joined #lisp",
+                         "to_me"   : False }
+    pdb.set_trace()
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    printall(incoming_message, response_actions,start_time)
+
+def test_system_1():
+    fenton_writes_on_lisp()
+
+    # Wait 2 seconds
+    print_sep(sleep_seconds = 2)
+    
+    incoming_message = { "from_who": "john",
+                         "channel" : "lisp",
+                         "message" : "this is barrys mess!",
+                         "to_me"   : False }
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    printall(incoming_message, response_actions,start_time)
+    perform_actions(response_actions,printer)
+    
+    print_sep(sleep_seconds = 4)
+    
+    incoming_message = { "from_who": "barry",
+                         "channel" : "lisp",
+                         "message" : "Let me look",
+                         "to_me"   : False }
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    printall(incoming_message, response_actions,start_time)
+    perform_actions(response_actions,printer)
+    
+    print_sep(sleep_seconds = 2)
+    
+    incoming_message = { "from_who": "barry",
+                         "channel" : "lisp",
+                         "message" : "Fenton this is really your mess!",
+                         "to_me"   : True }
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    printall(incoming_message, response_actions,start_time)
+    perform_actions(response_actions,printer)
+    
+    print_sep(sleep_seconds = 2)
+    
+    incoming_message = { "from_who": "fenton",
+                         "channel" : "lisp",
+                         "message" : "Ok I'll clean it up",
+                         "to_me"   : False }
+    response_actions = generate_actions_from_irc_message(incoming_message,printer)
+    printall(incoming_message, response_actions,start_time)
+    perform_actions(response_actions,printer)
+
+#########################
+## UNIT TESTS
+
+def unit_tests():
+    test_trim_leading_dashes()
+    test_begins_with_dash ()
+
+def test_trim_leading_dashes():
+    strng = "-abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+    strng = "--abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+    strng = "abc"
+    result = trim_leading_dashes(strng)
+    assert result == "abc"
+
+def test_begins_with_dash ():
+    strng = "-abc"
+    result = begins_with_dash(strng)
+    assert result == True
+    strng = "--abc"
+    result = begins_with_dash(strng)
+    assert result == True
+    strng = "abc"
+    result = begins_with_dash(strng)
+    assert result == False
+
+
+# test_system()
+# test_ignore_join_leave()
+
 if __name__ == '__main__':
-    _tests()
+    unit_tests()
+    system_tests()
